==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => '&#12507;&#12540;&#12512;',
'articles' => '&#35352;&#20107;',
'articles_auteur' => '&#12371;&#12398;&#35352;&#20107;&#12398;&#33879;&#32773;',
'articles_populaires' => '&#26368;&#12418;&#35501;&#12414;&#12428;&#12390;&#12356;&#12427;&#35352;&#20107;',
'articles_rubrique' => '&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12398;&#35352;&#20107;',
'aucun_article' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#35352;&#20107;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucun_auteur' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#33879;&#32773;&#12399;&#12356;&#12414;&#12379;&#12435;',
'aucun_site' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12469;&#12452;&#12488;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucune_breve' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12491;&#12517;&#12540;&#12473;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucune_rubrique' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12475;&#12463;&#12471;&#12519;&#12531;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'autres_breves' => '&#20182;&#12398;&#12491;&#12517;&#12540;&#12473;',
'autres_groupes_mots_clefs' => '&#12461;&#12540;&#12527;&#12540;&#12489;&#12398;&#20182;&#12398;&#12464;&#12523;&#12540;&#12503;',
'autres_sites' => '&#20182;&#12398;&#12469;&#12452;&#12488;',

// B
'bonjour' => '&#12362;&#12399;&#12424;&#12358;&#12372;&#12374;&#12356;&#12414;&#12377;',
'breves' => '&#12491;&#12517;&#12540;&#12473;',

// C
'commenter_site' => '&#12371;&#12398;&#12469;&#12452;&#12488;&#12395;&#12388;&#12356;&#12390;&#12467;&#12513;&#12531;&#12488;&#12375;&#12390;&#19979;&#12373;&#12356;',

// D
'date' => '&#26085;&#20184;',
'dernier_ajout' => '&#26368;&#26032;&#12398;&#36861;&#21152;',
'dernieres_breves' => '&#26368;&#26032;&#12398;&#12491;&#12517;&#12540;&#12473;',
'derniers_articles' => '&#26368;&#26032;&#12398;&#35352;&#20107;',
'derniers_commentaires' => '&#26368;&#26032;&#12398;&#12467;&#12513;&#12531;&#12488;',
'derniers_messages_forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12391;&#25237;&#31295;&#12373;&#12428;&#12383;&#26368;&#26032;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;',

// E
'edition_mode_texte' => '&#12486;&#12461;&#12473;&#12488;&#12514;&#12540;&#12489;only',
'en_reponse' => 'Replying to:',
'en_resume' => '&#12414;&#12392;&#12417;',
'envoyer_message' => '&#12513;&#12483;&#12475;&#12540;&#12472;&#12434;&#36865;&#12427;',
'espace_prive' => '&#12503;&#12521;&#12452;&#12505;&#12540;&#12488;&#12456;&#12522;&#12450;',

// F
'forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;',

// H
'hierarchie_site' => '&#12469;&#12452;&#12488;&#12398;&#38542;&#23652;',

// J
'jours' => '&#26085;&#20184;&#12369;',

// M
'meme_auteur' => '&#21516;&#12376;&#33879;&#32773;&#12395;&#12424;&#12387;&#12390;',
'meme_rubrique' => '&#21516;&#12376;&#12475;&#12463;&#12471;&#12519;&#12531;&#12398;&#20013;&#12391;',
'memes_auteurs' => '&#21516;&#12376;&#33879;&#32773;&#12395;&#12424;&#12387;&#12390;',
'message' => '&#12513;&#12483;&#12475;&#12540;&#12472;',
'messages_forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12513;&#12483;&#12475;&#12540;&#12472;',
'messages_recents' => '&#26368;&#12418;&#26032;&#12375;&#12356;&#12501;&#12457;&#12540;&#12521;&#12512;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;',
'mots_clefs' => '&#12461;&#12540;&#12527;&#12540;&#12489;',
'mots_clefs_meme_groupe' => '&#21516;&#12376;&#12464;&#12523;&#12540;&#12503;&#12398;&#12461;&#12540;&#12527;&#12540;&#12489;',

// N
'navigation' => '&#12490;&#12499;&#12466;&#12540;&#12471;&#12519;&#12531;',
'nom' => '&#21517;&#21069;',
'nouveautes' => '&#26032;&#12375;&#12356;&#12418;&#12398;',
'nouveautes_web' => 'Web&#12398;&#20013;&#12391;&#26032;&#12375;&#12356;&#12418;&#12398;',
'nouveaux_articles' => '&#26032;&#12375;&#12356;&#35352;&#20107;',
'nouvelles_breves' => '&#26032;&#12375;&#12356;&#12491;&#12517;&#12540;&#12473;',

// P
'page_precedente' => '&#21069;&#12398;&#12506;&#12540;&#12472;',
'page_suivante' => '&#27425;&#12398;&#12506;&#12540;&#12472;',
'par_auteur' => '&#12395;&#12424;&#12387;&#12390; ',
'participer_site' => '&#12354;&#12394;&#12383;&#12399;&#12371;&#12398;&#12454;&#12455;&#12502;&#12469;&#12452;&#12488;&#12391;&#27963;&#21205;&#12377;&#12427;&#12371;&#12392;&#12395;&#12424;&#12387;&#12390;&#12289;&#30331;&#37682;&#24460;&#12289;&#12354;&#12394;&#12383;&#12398;&#35352;&#20107;&#12434;&#26360;&#12367;&#12371;&#12392;&#12364;&#20986;&#26469;&#12414;&#12377;&#12290;&#12381;&#12428;&#12363;&#12425;&#12354;&#12394;&#12383;&#12399;&#12377;&#12368;&#12395;&#12289;&#12469;&#12452;&#12488;&#12398;&#12503;&#12521;&#12452;&#12505;&#12540;&#12488;&#12456;&#12522;&#12450;&#12408;&#12398;&#12450;&#12463;&#12475;&#12473;&#12467;&#12540;&#12489;&#12434;&#12289;email&#12395;&#12424;&#12387;&#12390;&#24471;&#12425;&#12428;&#12427;&#12391;&#12375;&#12423;&#12358;&#12290;',
'plan_site' => '&#12469;&#12452;&#12488;&#12510;&#12483;&#12503;',
'popularite' => '&#12509;&#12500;&#12517;&#12521;&#12540;',
'poster_message' => '&#12513;&#12483;&#12475;&#12540;&#12472;&#12434;&#25237;&#31295;',
'proposer_site' => '&#12354;&#12394;&#12383;&#12399;&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12395;&#36861;&#21152;&#12377;&#12427;&#12469;&#12452;&#12488;&#12434;&#25552;&#26696;&#12377;&#12427;&#12371;&#12392;&#12364;&#20986;&#26469;&#12414;&#12377;:',

// R
'repondre_article' => '&#12371;&#12398;&#35352;&#20107;&#12395;&#36820;&#20449;',
'repondre_breve' => '&#12371;&#12398;&#12491;&#12517;&#12540;&#12473;&#12395;&#36820;&#20449;',
'repondre_message' => '&#12371;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;&#12395;&#36820;&#20449;',
'resultats_recherche' => '&#26908;&#32034;&#32080;&#26524;',
'retour_debut_forums' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12398;&#26368;&#21021;&#12398;&#12506;&#12540;&#12472;&#12395;&#25147;&#12427;',
'rubrique' => '&#12475;&#12463;&#12471;&#12519;&#12531;',
'rubriques' => '&#12475;&#12463;&#12471;&#12519;&#12531;',

// S
'signatures_petition' => '&#32626;&#21517;',
'site_realise_avec_spip' => 'SPIP&#12395;&#12424;&#12387;&#12390;&#12469;&#12452;&#12488;&#12399;&#20316;&#12425;&#12428;&#12414;&#12375;&#12383;',
'sites_web' => '&#12454;&#12455;&#12502;&#12469;&#12452;&#12488;',
'sous_rubriques' => '&#12469;&#12502;&#12475;&#12463;&#12471;&#12519;&#12531;',
'suite' => '&#27425;&#12398;',
'sur_web' => '&#12454;&#12455;&#12502;&#19978;',
'syndiquer_rubrique' => '&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12434;&#20379;&#32102;&#12377;&#12427;',
'syndiquer_site' => '&#12469;&#12452;&#12488;&#20840;&#20307;&#12434;&#20379;&#32102;&#12377;&#12427;',

// T
'texte_lettre_information' => '&#12469;&#12452;&#12488;&#12398;&#12491;&#12517;&#12540;&#12473;&#12524;&#12479;&#12540;&#12399;&#12371;&#12371;',
'texte_lettre_information_2' => '&#12371;&#12398;&#25163;&#32025;&#12399;&#12289;&#20197;&#26469;&#20844;&#34920;&#12373;&#12428;&#12383;&#35352;&#20107;&#12392;&#12491;&#12517;&#12540;&#12473;&#12434;&#12414;&#12392;&#12417;&#12390;&#12354;&#12426;&#12414;&#12377;&#12290;',

// V
'ver_imprimer' => '&#12496;&#12540;&#12472;&#12519;&#12531;&#34920;&#35352;',
'voir_en_ligne' => '&#12458;&#12531;&#12521;&#12452;&#12531;&#12434;&#35211;&#12427;',
'voir_squelette' => '<MODIF>???????????????'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => '&#12507;&#12540;&#12512;',
'article' => 'Article', # NEW
'articles' => '&#35352;&#20107;',
'articles_auteur' => '&#12371;&#12398;&#35352;&#20107;&#12398;&#33879;&#32773;',
'articles_populaires' => '&#26368;&#12418;&#35501;&#12414;&#12428;&#12390;&#12356;&#12427;&#35352;&#20107;',
'articles_rubrique' => '&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12398;&#35352;&#20107;',
'aucun_article' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#35352;&#20107;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucun_auteur' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#33879;&#32773;&#12399;&#12356;&#12414;&#12379;&#12435;',
'aucun_site' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12469;&#12452;&#12488;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucune_breve' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12491;&#12517;&#12540;&#12473;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'aucune_rubrique' => '&#12371;&#12398;&#12450;&#12489;&#12524;&#12473;&#12395;&#12475;&#12463;&#12471;&#12519;&#12531;&#12399;&#12354;&#12426;&#12414;&#12379;&#12435;',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => '&#20182;&#12398;&#12491;&#12517;&#12540;&#12473;',
'autres_groupes_mots_clefs' => '&#12461;&#12540;&#12527;&#12540;&#12489;&#12398;&#20182;&#12398;&#12464;&#12523;&#12540;&#12503;',
'autres_sites' => '&#20182;&#12398;&#12469;&#12452;&#12488;',

// B
'bonjour' => '&#12362;&#12399;&#12424;&#12358;&#12372;&#12374;&#12356;&#12414;&#12377;',
'breve' => 'Br&egrave;ve', # NEW
'breves' => '&#12491;&#12517;&#12540;&#12473;',

// C
'commenter_site' => '&#12371;&#12398;&#12469;&#12452;&#12488;&#12395;&#12388;&#12356;&#12390;&#12467;&#12513;&#12531;&#12488;&#12375;&#12390;&#19979;&#12373;&#12356;',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => '&#26085;&#20184;',
'dernier_ajout' => '&#26368;&#26032;&#12398;&#36861;&#21152;',
'dernieres_breves' => '&#26368;&#26032;&#12398;&#12491;&#12517;&#12540;&#12473;',
'derniers_articles' => '&#26368;&#26032;&#12398;&#35352;&#20107;',
'derniers_commentaires' => '&#26368;&#26032;&#12398;&#12467;&#12513;&#12531;&#12488;',
'derniers_messages_forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12391;&#25237;&#31295;&#12373;&#12428;&#12383;&#26368;&#26032;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => '&#12486;&#12461;&#12473;&#12488;&#12514;&#12540;&#12489;only',
'en_reponse' => 'Replying to:',
'en_resume' => '&#12414;&#12392;&#12417;',
'envoyer_message' => '&#12513;&#12483;&#12475;&#12540;&#12472;&#12434;&#36865;&#12427;',
'espace_prive' => '&#12503;&#12521;&#12452;&#12505;&#12540;&#12488;&#12456;&#12522;&#12450;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;',

// H
'hierarchie_site' => '&#12469;&#12452;&#12488;&#12398;&#38542;&#23652;',

// J
'jours' => '&#26085;&#20184;&#12369;',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => '&#21516;&#12376;&#33879;&#32773;&#12395;&#12424;&#12387;&#12390;',
'meme_rubrique' => '&#21516;&#12376;&#12475;&#12463;&#12471;&#12519;&#12531;&#12398;&#20013;&#12391;',
'memes_auteurs' => '&#21516;&#12376;&#33879;&#32773;&#12395;&#12424;&#12387;&#12390;',
'message' => '&#12513;&#12483;&#12475;&#12540;&#12472;',
'messages_forum' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12513;&#12483;&#12475;&#12540;&#12472;',
'messages_recents' => '&#26368;&#12418;&#26032;&#12375;&#12356;&#12501;&#12457;&#12540;&#12521;&#12512;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => '&#12461;&#12540;&#12527;&#12540;&#12489;',
'mots_clefs_meme_groupe' => '&#21516;&#12376;&#12464;&#12523;&#12540;&#12503;&#12398;&#12461;&#12540;&#12527;&#12540;&#12489;',

// N
'navigation' => '&#12490;&#12499;&#12466;&#12540;&#12471;&#12519;&#12531;',
'nom' => '&#21517;&#21069;',
'nouveautes' => '&#26032;&#12375;&#12356;&#12418;&#12398;',
'nouveautes_web' => 'Web&#12398;&#20013;&#12391;&#26032;&#12375;&#12356;&#12418;&#12398;',
'nouveaux_articles' => '&#26032;&#12375;&#12356;&#35352;&#20107;',
'nouvelles_breves' => '&#26032;&#12375;&#12356;&#12491;&#12517;&#12540;&#12473;',

// P
'page_precedente' => '&#21069;&#12398;&#12506;&#12540;&#12472;',
'page_suivante' => '&#27425;&#12398;&#12506;&#12540;&#12472;',
'par_auteur' => '&#12395;&#12424;&#12387;&#12390; ',
'participer_site' => '&#12354;&#12394;&#12383;&#12399;&#12371;&#12398;&#12454;&#12455;&#12502;&#12469;&#12452;&#12488;&#12391;&#27963;&#21205;&#12377;&#12427;&#12371;&#12392;&#12395;&#12424;&#12387;&#12390;&#12289;&#30331;&#37682;&#24460;&#12289;&#12354;&#12394;&#12383;&#12398;&#35352;&#20107;&#12434;&#26360;&#12367;&#12371;&#12392;&#12364;&#20986;&#26469;&#12414;&#12377;&#12290;&#12381;&#12428;&#12363;&#12425;&#12354;&#12394;&#12383;&#12399;&#12377;&#12368;&#12395;&#12289;&#12469;&#12452;&#12488;&#12398;&#12503;&#12521;&#12452;&#12505;&#12540;&#12488;&#12456;&#12522;&#12450;&#12408;&#12398;&#12450;&#12463;&#12475;&#12473;&#12467;&#12540;&#12489;&#12434;&#12289;email&#12395;&#12424;&#12387;&#12390;&#24471;&#12425;&#12428;&#12427;&#12391;&#12375;&#12423;&#12358;&#12290;',
'plan_site' => '&#12469;&#12452;&#12488;&#12510;&#12483;&#12503;',
'popularite' => '&#12509;&#12500;&#12517;&#12521;&#12540;',
'poster_message' => '&#12513;&#12483;&#12475;&#12540;&#12472;&#12434;&#25237;&#31295;',
'proposer_site' => '&#12354;&#12394;&#12383;&#12399;&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12395;&#36861;&#21152;&#12377;&#12427;&#12469;&#12452;&#12488;&#12434;&#25552;&#26696;&#12377;&#12427;&#12371;&#12392;&#12364;&#20986;&#26469;&#12414;&#12377;:',

// R
'repondre_article' => '&#12371;&#12398;&#35352;&#20107;&#12395;&#36820;&#20449;',
'repondre_breve' => '&#12371;&#12398;&#12491;&#12517;&#12540;&#12473;&#12395;&#36820;&#20449;',
'repondre_message' => '&#12371;&#12398;&#12513;&#12483;&#12475;&#12540;&#12472;&#12395;&#36820;&#20449;',
'resultats_recherche' => '&#26908;&#32034;&#32080;&#26524;',
'retour_debut_forums' => '&#12501;&#12457;&#12540;&#12521;&#12512;&#12398;&#26368;&#21021;&#12398;&#12506;&#12540;&#12472;&#12395;&#25147;&#12427;',
'rubrique' => '&#12475;&#12463;&#12471;&#12519;&#12531;',
'rubriques' => '&#12475;&#12463;&#12471;&#12519;&#12531;',

// S
'signatures_petition' => '&#32626;&#21517;',
'site_realise_avec_spip' => 'SPIP&#12395;&#12424;&#12387;&#12390;&#12469;&#12452;&#12488;&#12399;&#20316;&#12425;&#12428;&#12414;&#12375;&#12383;',
'sites_web' => '&#12454;&#12455;&#12502;&#12469;&#12452;&#12488;',
'sous_rubriques' => '&#12469;&#12502;&#12475;&#12463;&#12471;&#12519;&#12531;',
'spam' => 'Spam', # NEW
'suite' => '&#27425;&#12398;',
'sur_web' => '&#12454;&#12455;&#12502;&#19978;',
'syndiquer_rubrique' => '&#12371;&#12398;&#12475;&#12463;&#12471;&#12519;&#12531;&#12434;&#20379;&#32102;&#12377;&#12427;',
'syndiquer_site' => '&#12469;&#12452;&#12488;&#20840;&#20307;&#12434;&#20379;&#32102;&#12377;&#12427;',

// T
'texte_lettre_information' => '&#12469;&#12452;&#12488;&#12398;&#12491;&#12517;&#12540;&#12473;&#12524;&#12479;&#12540;&#12399;&#12371;&#12371;',
'texte_lettre_information_2' => '&#12371;&#12398;&#25163;&#32025;&#12399;&#12289;&#20197;&#26469;&#20844;&#34920;&#12373;&#12428;&#12383;&#35352;&#20107;&#12392;&#12491;&#12517;&#12540;&#12473;&#12434;&#12414;&#12392;&#12417;&#12390;&#12354;&#12426;&#12414;&#12377;&#12290;',

// V
'ver_imprimer' => '&#12496;&#12540;&#12472;&#12519;&#12531;&#34920;&#35352;',
'voir_en_ligne' => '&#12458;&#12531;&#12521;&#12452;&#12531;&#12434;&#35211;&#12427;',
'voir_squelette' => '<MODIF>???????????????'
);

?>
